using System.Net.Http;
using Ninject;
using Ninject.Modules;

namespace TourDataManager {

    public class TourDataManager {
        private string persistentPath;

        private IKernel Container;
        
        public TourDataManager(string persistentPath){
            this.persistentPath = persistentPath;
            Container = new StandardKernel(new MyModule(persistentPath));
        }

        public void Login(string email, string password){
            Container.Get<IAuthenticator>().Login(email,password, (b, s) => {
                var cookiestor = Container.Get<CookieStorage>();
                Debug.Log($"Authorization : {s}");
                Debug.Log($"Cookie count in storage : {cookiestor.Get().Count}");
                cookiestor.Save();
            });
        }
    }

    public class MyModule : NinjectModule {

        private readonly string persistentPath;
        
        public MyModule(string persistentPath){
            this.persistentPath = persistentPath;
        }

        public override void Load(){
            var cookieStorage = new CookieStorage(persistentPath + "\\cookie.storage");
            var httpClientHandler = new HttpClientHandler();
            //CookieContainer сам запоминает полученные из ответа куки
            httpClientHandler.CookieContainer = cookieStorage.Get();
            var httpClient = new HttpClient(httpClientHandler);
            
            
            Bind<CookieStorage>().ToConstant(cookieStorage).InSingletonScope();
            Bind<HttpClientHandler>().ToConstant(httpClientHandler).InSingletonScope();
            Bind<HttpClient>().ToConstant(httpClient).InSingletonScope();
            Bind<IAuthenticator>().To<Authenticator>().InSingletonScope();
            
        }
    }
}